@@ -32,6 +32,11 @@
 void sql_conn_open_cb (GtkWidget * widget, ConfManager * conf);
 void sql_conn_close_cb (GtkWidget * widget, ConfManager * conf);
 
+/* CB to attach to transaction-related menu items */
+void sql_begin_trans_cb (GtkWidget * widget, ConfManager * conf);
+void sql_commit_trans_cb (GtkWidget * widget, ConfManager * conf);
+void sql_rollback_trans_cb (GtkWidget * widget, ConfManager * conf);
+
 /* CB to attach to connections preferences */
 void options_config_cb (GtkWidget * widget, ConfManager * conf);
 
@@ -53,6 +58,13 @@ void users_settings_cb (GObject * obj, ConfManager * conf);
 void users_access_cb (GObject * obj, ConfManager * conf);
 void users_groups_cb (GObject * obj, ConfManager * conf);
 
+/* CBs for the view menu */
+void view_tables_tab_cb (GtkWidget * widget, ConfManager * conf);
+void view_sequences_tab_cb (GtkWidget * widget, ConfManager * conf);
+void view_queries_tab_cb (GtkWidget * widget, ConfManager * conf);
+void view_forms_tab_cb (GtkWidget * widget, ConfManager * conf);
+void view_sql_tab_cb (GtkWidget * widget, ConfManager * conf);
+
 /* CB for the printer stuff */
 void printer_setup_cb (GObject * obj, ConfManager * conf);
 
@@ -92,6 +104,7 @@ void sql_server_conn_close_cb (GObject * wid, ConfManager * conf);
 void wid_db_rel_list_update (GObject * obj, gpointer item,
 			     ConfManager * conf);
 
-/* CB to link to the "error" signal of ServerAccess */
-void sql_server_catch_errors_cb (ServerAccess * srv, GdaConnection *cnc,
-				 GList * error_list, ConfManager * conf);
+/* CB to link to the "event_notification" signal of ServerAccess */
+void sql_server_event_cb (ServerAccess * srv, GdaConnection *cnc,
+			  GdaClientEvent event, GdaParameterList *params,
+			  ConfManager * conf);
